

#include "utils.h"
#include "crypto.h"

#include <iostream>
#include <iomanip>
#include <sstream>


const char *k_szEUDPPktTypes[] =
{
	"Invalid EUDPPktType",

	"k_EUDPPktTypeChallengeReq",
	"k_EUDPPktTypeChallenge",
	"k_EUDPPktTypeConnect",
	"k_EUDPPktTypeAccept",
	"k_EUDPPktTypeDisconnect",
	"k_EUDPPktTypeData",
	"k_EUDPPktTypeDatagram",
};

const char *PchStringFromUDPPktHdr( const UDPPktHdr_t *pHdr )
{
	static char szBuff[ 1024 * 8 ];
	memset( szBuff, 0, sizeof( szBuff ) );

	sprintf_s( szBuff, sizeof( szBuff ),

		"UDPPktHdr\r\n"
		"  m_cbPkt = %u bytes\r\n"
		"  m_EUDPPktType = %s (%u)\r\n"
		"  m_nFlags = %s (%u)\r\n"
		"  m_nSrcConnectionID = %u\r\n"
		"  m_nDstConnectionID = %u\r\n"
		"  m_nSeqThis = %u\r\n"
		"  m_nSeqAcked = %u\r\n"
		"  m_nPktsInMsg = %u\r\n"
		"  m_nMsgStartSeq = %u\r\n"
		"  m_cbMsgData = %u\r\n",

		pHdr->m_cbPkt,
		PchNameFromEUDPPktType( (EUDPPktType)pHdr->m_EUDPPktType ), pHdr->m_EUDPPktType,
		PchNameFromNetFlags( pHdr->m_nFlags ), pHdr->m_nFlags,
		pHdr->m_nSrcConnectionID,
		pHdr->m_nDstConnectionID,
		pHdr->m_nSeqThis,
		pHdr->m_nSeqAcked,
		pHdr->m_nPktsInMsg,
		pHdr->m_nMsgStartSeq,
		pHdr->m_cbMsgData
	);

	return szBuff;

}

const char *PchStringFromMsgHdr( const MsgHdr_t *pMsgHdr )
{
	static char szBuff[ 1024 * 8 ];
	memset( szBuff, 0, sizeof( szBuff ) );

	sprintf_s( szBuff, sizeof( szBuff ),

		"   MsgHdr_t\r\n"
		"    m_EMsg = %s (%u)\r\n"
		"    m_JobIDTarget = %llu\r\n"
		"    m_JobIDSource = %llu\r\n",

		g_Crypto->GetMessage( (EMsg)pMsgHdr->m_EMsg ), pMsgHdr->m_EMsg,
		pMsgHdr->m_JobIDTarget,
		pMsgHdr->m_JobIDSource

	);

	return szBuff;
}

const char *PchStringFromExtendedClientMsgHdr( const ExtendedClientMsgHdr_t *pMsgHdr )
{
	static char szBuff[ 1024 * 8 ];
	memset( szBuff, 0, sizeof( szBuff ) );

	const CSteamID *steamId = &pMsgHdr->m_ulSteamID;

	sprintf_s( szBuff, sizeof( szBuff ),

		"   ExtendedClientMsgHdr_t\r\n"
		"    m_EMsg = %s (%u)\r\n"
		"    m_nCubHdr = %u\r\n"
		"    m_nHdrVersion = %u\r\n"
		"    m_JobIDTarget = %llu\r\n"
		"    m_JobIDSource = %llu\r\n"
		"    m_nHdrCanary = %u\r\n"
		"    m_ulSteamID = %s %s (%llu) (id = %d, instance = %d, type = %s (%d), universe = %s (%d))\r\n"
		"    m_nSessionID = %u\r\n",

		g_Crypto->GetMessage( (EMsg)pMsgHdr->m_EMsg ), pMsgHdr->m_EMsg,
		pMsgHdr->m_nCubHdr,
		pMsgHdr->m_nHdrVersion,
		pMsgHdr->m_JobIDTarget,
		pMsgHdr->m_JobIDSource,
		pMsgHdr->m_nHdrCanary,
		steamId->Render(), steamId->SteamRender(), steamId->ConvertToUint64(),
		steamId->GetAccountID(), steamId->GetUnAccountInstance(), PchNameFromEAccountType( steamId->GetEAccountType() ), steamId->GetEAccountType(),
		PchNameFromEUniverse( steamId->GetEUniverse() ), steamId->GetEUniverse(),
		pMsgHdr->m_nSessionID

	);

	return szBuff;
}

char *szData = NULL;
const char *PchStringFromData( const uint8 *pData, uint32 cubData )
{
	if ( cubData == 0 )
		return "";

	uint32 memSize = cubData * 4;

	szData = (char *)realloc( szData, memSize );
	memset( szData, 0, memSize );

	for ( uint32 x = 0; x < cubData; ++x )
	{
		sprintf_s( szData, memSize, "%s%02X ", szData, (uint8 )pData[ x ] );

		if ( ( x + 1 ) % 12 == 0 )
			sprintf_s( szData, memSize, "%s\r\n    ", szData );
	}

	return szData;
}

const char *PchNameFromEUDPPktType( EUDPPktType eUdpPktType )
{
	if ( eUdpPktType <= 0 || eUdpPktType >= k_EUDPPktTypeMax )
		return k_szEUDPPktTypes[ 0 ];

	return k_szEUDPPktTypes[ (int)eUdpPktType ];
}

const char *PchNameFromNetFlags( uint32 netFlags )
{
	static char szBuff[ 1024 ];
	memset( szBuff, 0, sizeof( szBuff ) );

	std::string str = "";

	if ( netFlags & k_uNetFlagNoIOCP )
		str += "k_uNetFlagNoIOCP ";

	if ( netFlags & k_uNetFlagFindAvailPort )
		str += "k_uNetFlagFindAvailPort ";

	if ( netFlags & k_uNetFlagUseAuthentication )
		str += "k_uNetFlagUseAuthentication ";

	if ( netFlags & k_uNetFlagUseEncryption )
		str += "k_uNetFlagUseEncryption ";

	if ( netFlags & k_uNetFlagRawStream )
		str += "k_uNetFlagRawStream ";

	if ( netFlags & k_uNetFlagRawStreamSend )
		str += "k_uNetFlagRawStreamSend ";

	if ( netFlags & k_uNetFlagUnboundSocket )
		str += "k_uNetFlagUnboundSocket ";

	if ( netFlags & k_uNetFlagRawIORecv )
		str += "k_uNetFlagRawIORecv ";

	const char *cStr = str.c_str();
	strcpy_s( szBuff, sizeof( szBuff ), cStr );

	return szBuff;
}

const char *k_szUniverse[] =
{
	"k_EUniverseInvalid",

	"k_EUniversePublic",
	"k_EUniverseBeta",
	"k_EUniverseInternal",
	"k_EUniverseDev",
	"k_EUniverseRC",

};

const char *PchNameFromEUniverse( EUniverse eUniverse )
{
	static char szBuff[ 1024 ];
	memset( szBuff, 0, sizeof( szBuff ) );

	if ( eUniverse <= k_EUniverseInvalid || eUniverse >= k_EUniverseMax )
		return k_szUniverse[ 0 ];

	return k_szUniverse[ (int)eUniverse ];
}

// fuck me.
const char *k_szEMsg[] =
{
	"k_EMsgInvalid",
	"k_EMsgMulti",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"k_EMsgGenericReply",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"k_EMsgDestJobFailed",
	"",
	"k_EMsgAlert",
	"",
	"",
	"",
	"",
	"k_EMsgSCIDRequest",
	"k_EMsgSCIDResponse",
	"",
	"k_EMsgJobHeartbeat",
	"",
	"k_EMsgStats",
	"k_EMsgSubscribe",
	"k_EMRouteMessage",
	"k_EMsgRemoteSysID",
	"k_EMsgAMCreateAccountResponse",
	"k_EMsgWGRequest",
	"k_EMsgWGResponse",
	"k_EMsgKeepAlive",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"k_EMsgAssignSysID",
	"k_EMsgExit",
	"k_EMsgDirRequest",
	"k_EMsgDirResponse",
	"k_EMsgZipRequest",
	"k_EMsgZipResponse",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"k_EMsgUpdateRecordResponse",
	"",
	"",
	"",
	"",
	"",
	"k_EMsgUpdateCreditCardRequest",
	"",
	"",
	"",
	"k_EMsgUpdateUserBanResponse",
	"k_EMsgPrepareToExit",
	"k_EMsgContentDescriptionUpdate",
	"k_EMsgTestResetServer",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"k_EMsgHeartbeat",
	"k_EMsgShellFailed",
	"",
	"",
	"",
	"",
	"",
	"k_EMsgExitShells",
	"k_EMsgExitShell",
	"k_EMsgGracefulExitShell",
	"",
	"",
	"",
	"",
	"k_EMsgNotifyWatchdog",
	"",
	"k_EMsgLicenseProcessingComplete",
	"k_EMsgSetTestFlag",
	"k_EMsgQueuedEmailsComplete",
	"k_EMsgGMReportPHPError",
	"k_EMsgGMDRMSync",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"k_EMsgBaseAIS",
	"k_EMsgAISRefreshContentDescription",
	"k_EMsgAISRequestContentDescription",
	"k_EMsgAISUpdateAppInfo",
	"k_EMsgAISUpdatePackageInfo",
	"k_EMsgAISGetPackageChangeNumber",
	"k_EMsgAISGetPackageChangeNumberResponse",
	"k_EMsgAISAppInfoTableChanged",
	"k_EMsgAISUpdatePackageInfoResponse",
	"k_EMsgAISCreateMarketingMessage",
	"k_EMsgAISCreateMarketingMessageResponse",
	"k_EMsgAISGetMarketingMessage",
	"k_EMsgAISGetMarketingMessageResponse",
	"k_EMsgAISUpdateMarketingMessage",
	"k_EMsgAISUpdateMarketingMessageResponse",
	"k_EMsgAISRequestMarketingMessageUpdate",
	"k_EMsgAISDeleteMarketingMessage",
	"",
	"",
	"k_EMsgAISGetMarketingTreatments",
	"k_EMsgAISGetMarketingTreatmentsResponse",
	"k_EMsgAISRequestMarketingTreatmentUpdate",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"k_EMsgBaseAM",
	"",
	"",
	"",
	"k_EMsgAMUpdateUserBanRequest",
	"k_EMsgAMAddLicense",
	"",
	"k_EMsgAMBeginProcessingLicenses",
	"k_EMsgAMSendSystemIMToUser",
	"k_EMsgAMExtendLicense",
	"k_EMsgAMAddMinutesToLicense",
	"k_EMsgAMCancelLicense",
	"k_EMsgAMInitPurchase",
	"k_EMsgAMPurchaseResponse",
	"k_EMsgAMGetFinalPrice",
	"k_EMsgAMGetFinalPriceResponse",
	"k_EMsgAMGetLegacyGameKey",
	"k_EMsgAMGetLegacyGameKeyResponse",
	"k_EMsgAMFindHungTransactions",
	"k_EMsgAMSetAccountTrustedRequest",
	"",
	"k_EMsgAMCompletePurchase",
	"k_EMsgAMCancelPurchase",
	"k_EMsgAMNewChallenge",
	"",
	"",
	"k_EMsgAMFixPendingPurchase",
	"k_EMsgAMIsUserBanned",
	"k_EMsgAMRegisterKey",
	"k_EMsgAMLoadActivationCodes",
	"k_EMsgAMLoadActivationCodesResponse",
	"k_EMsgAMLookupKeyResponse",
	"k_EMsgAMLookupKey",
	"k_EMsgAMChatCleanup",
	"k_EMsgAMClanCleanup",
	"k_EMsgAMFixPendingRefund",
	"k_EMsgAMReverseChargeback",
	"k_EMsgAMReverseChargebackResponse",
	"k_EMsgAMClanCleanupList",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"k_EMsgAllowUserToPlayQuery",
	"k_EMsgAllowUserToPlayResponse",
	"k_EMsgAMVerfiyUser",
	"k_EMsgAMClientNotPlaying",
	"k_EMsgAMClientRequestFriendship",
	"k_EMsgAMRelayPublishStatus",
	"k_EMsgAMResetCommunityContent",
	"k_EMsgCAMPrimePersonaStateCache",
	"k_EMsgAMAllowUserContentQuery",
	"k_EMsgAMAllowUserContentResponse",
	"k_EMsgAMInitPurchaseResponse",
	"k_EMsgAMRevokePurchaseResponse",
	"k_EMsgAMLockProfile",
	"k_EMsgAMRefreshGuestPasses",
	"k_EMsgAMInviteUserToClan",
	"k_EMsgAMAcknowledgeClanInvite",
	"k_EMsgAMGrantGuestPasses",
	"k_EMsgAMClanDataUpdated",
	"k_EMsgAMReloadAccount",
	"k_EMsgAMClientChatMsgRelay",
	"k_EMsgAMChatMulti",
	"k_EMsgAMClientChatInviteRelay",
	"k_EMsgAMChatInvite",
	"k_EMsgAMClientJoinChatRelay",
	"k_EMsgAMClientChatMemberInfoRelay",
	"k_EMsgAMPublishChatMemberInfo",
	"k_EMsgAMClientAcceptFriendInvite",
	"k_EMsgAMChatEnter",
	"k_EMsgAMClientPublishRemovalFromSource",
	"k_EMsgAMChatActionResult",
	"k_EMsgAMFindAccounts",
	"k_EMsgAMFindAccountsResponse",
	"",
	"",
	"k_EMsgAMSetAccountFlags",
	"",
	"k_EMsgAMCreateClan",
	"k_EMsgAMCreateClanResponse",
	"k_EMsgAMGetClanDetails",
	"k_EMsgAMGetClanDetailsResponse",
	"k_EMsgAMSetPersonaName",
	"k_EMsgAMSetAvatar",
	"k_EMsgAMAuthenticateUser",
	"k_EMsgAMAuthenticateUserResponse",
	"k_EMsgAMGetAccountFriendsCount",
	"k_EMsgAMGetAccountFriendsCountResponse",
	"k_EMsgAMP2PIntroducerMessage",
	"k_EMsgClientChatAction",
	"k_EMsgAMClientChatActionRelay",
	"",
	"k_EMsgReqChallenge",
	"k_EMsgVACResponse",
	"k_EMsgReqChallengeTest",
	"k_EMsgVSInitDB",
	"k_EMsgVSMarkCheat",
	"k_EMsgVSAddCheat",
	"k_EMsgVSPurgeCodeModDB",
	"k_EMsgVSGetChallengeResults",
	"k_EMsgVSChallengeResultText",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"k_EMsgClientCSGetDepotManifestChunk",
	"",
	"",
	"",
	"",
	"k_EMsgBaseDRMS",
	"",
	"",
	"k_EMsgDRMBuildBlobRequest",
	"k_EMsgDRMBuildBlobResponse",
	"k_EMsgDRMResolveGuidRequest",
	"k_EMsgDRMResolveGuidResponse",
	"",
	"k_EMsgDRMVariabilityReport",
	"k_EMsgDRMVariabilityReportResponse",
	"k_EMsgDRMStabilityReport",
	"k_EMsgDRMStabilityReportResponse",
	"k_EMsgDRMDetailsReportRequest",
	"k_EMsgDRMDetailsReportResponse",
	"k_EMsgDRMProcessFile",
	"k_EMsgDRMAdminUpdate",
	"k_EMsgDRMAdminUpdateResponse",
	"k_EMsgDRMSync",
	"k_EMsgDRMSyncResposne",
	"k_EMsgDRMProcessFileResponse",
	"",
	"",
	"",
	"",
	"",
	"k_EMsgBaseCS",
	"k_EMsgCSManifestUpdate",
	"k_EMsgCSUserContentRequest",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"k_EMsgBaseClient",
	"k_EMsgClientLogOn",
	"k_EMsgClientAnonLogOn",
	"k_EMsgClientHeartBeat",
	"k_EMsgClientVACResponse",
	"k_EMsgClientGamesPlayed_obsolete",
	"k_EMsgClientLogOff",
	"k_EMsgClientNoUDPConnectivity",
	"k_EMsgClientInformOfCreateAccount",
	"k_EMsgClientAckVACBan",
	"k_EMsgClientConnectionStats",
	"k_EMsgClientInitPurchase",
	"k_EMsgClientPingResponse",
	"k_EMsgClientAddFriend",
	"k_EMsgClientRemoveFriend",
	"k_EMsgClientGamesPlayedNoDataBlob",
	"k_EMsgClientChangeStatus",
	"k_EMsgClientVacStatusResponse",
	"k_EMsgClientFriendMsg",
	"k_EMsgClientGameConnect_obsolete",
	"k_EMsgClientGamesPlayed2_obsolete",
	"k_EMsgClientGameEnded_obsolete",
	"k_EMsgClientGetFinalPrice",
	"",
	"",
	"",
	"k_EMsgClientSystemIM",
	"k_EMsgClientSystemIMAck",
	"k_EMsgClientGetLicenses",
	"k_EMsgClientCancelLicense",
	"k_EMsgClientGetLegacyGameKey",
	"k_EMsgClientContentServerLogOn",
	"k_EMsgClientAckVACBan2",
	"k_EMsgClientCompletePurchase",
	"k_EMsgClientCancelPurchase",
	"k_EMsgClientAckMessageByGID",
	"k_EMsgClientGetPurchaseReceipts",
	"k_EMsgClientAckPurchaseReceipt",
	"k_EMsgClientGamesPlayed3_obsolete",
	"k_EMsgClientSendGuestPass",
	"k_EMsgClientAckGuestPass",
	"k_EMsgClientRedeemGuestPass",
	"k_EMsgClientGamesPlayed",
	"k_EMsgClientRegisterKey",
	"k_EMsgClientInviteUserToClan",
	"k_EMsgClientAcknowledgeClanInvite",
	"k_EMsgClientPurchaseWithMachineID",
	"k_EMsgClientAppUsageEvent",
	"k_EMsgClientGetGiftTargetList",
	"k_EMsgClientGetGiftTargetListResponse",
	"",
	"k_EMsgClientLogOnResponse",
	"",
	"k_EMsgClientVACChallenge",
	"",
	"k_EMsgClientSetHeartbeatRate",
	"k_EMsgClientNotLoggedOnDeprecated",
	"k_EMsgClientLoggedOff",
	"k_EMsgGSApprove",
	"k_EMsgGSDeny",
	"k_EMsgGSKick",
	"k_EMsgClientCreateAcctResponse",
	"k_EMsgClientVACBanStatus",
	"k_EMsgClientPurchaseResponse",
	"k_EMsgClientPing",
	"k_EMsgClientNOP",
	"k_EMsgClientPersonaState",
	"k_EMsgClientFriendsList",
	"k_EMsgClientAccountInfo",
	"k_EMsgClientAddFriendResponse",
	"k_EMsgClientVacStatusQuery",
	"k_EMsgClientNewsUpdate",
	"",
	"k_EMsgClientGameConnectDeny",
	"k_EMsgGSStatusReply",
	"k_EMsgClientGetFinalPriceResponse",
	"",
	"",
	"",
	"k_EMsgClientGameConnectTokens",
	"k_EMsgClientLicenseList",
	"k_EMsgClientCancelLicenseResponse",
	"k_EMsgClientVACBanStatus2",
	"k_EMsgClientCMList",
	"k_EMsgClientEncryptPct",
	"k_EMsgClientGetLegacyGameKeyResponse",
	"k_EMsgClientFavoritesList",
	"k_EMsgCSUserContentApprove",
	"k_EMsgCSUserContentDeny",
	"k_EMsgClientInitPurchaseResponse",
	"k_EMsgClientGetPurchaseReceiptsResponse",
	"k_EMsgClientAddFriend2",
	"k_EMsgClientAddFriendResponse2",
	"k_EMsgClientInviteFriend",
	"k_EMsgClientInviteFriendResponse",
	"k_EMsgClientSendGuestPassResponse",
	"k_EMsgClientAckGuestPassResponse",
	"k_EMsgClientRedeemGuestPassResponse",
	"k_EMsgClientUpdateGuestPassesList",
	"k_EMsgClientChatMsg",
	"k_EMsgClientChatInvite",
	"k_EMsgClientJoinChat",
	"k_EMsgClientChatMemberInfo",
	"k_EMsgClientLogOnWithCredentials",
	"k_EMsgClientPasswordChange",
	"k_EMsgClientPasswordChangeResponse",
	"",
	"k_EMsgClientChatEnter",
	"k_EMsgClientFriendRemovedFromSource",
	"k_EMsgClientCreateChat",
	"k_EMsgClientCreateChatResponse",
	"k_EMsgClientUpdateChatMetadata",
	"k_EMsgClientP2PTrackerMessage",
	"k_EMsgClientP2PIntroducerMessage",
	"k_EMsgClientChatActionResult",
	"k_EMsgClientRequestFriendData",
	"k_EMsgClientOneTimeWGAuthPassword",
	"",
	"k_EMsgClientGetUserStats",
	"k_EMsgClientGetUserStatsResponse",
	"k_EMsgClientStoreUserStats",
	"k_EMsgClientStoreUserStatsResponse",
	"k_EMsgClientClanState",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"k_EMsgClientServiceModule",
	"k_EMsgClientServiceCall",
	"k_EMsgClientServiceCallResponse",
	"",
	"",
	"",
	"",
	"",
	"",
	"k_EMsgClientNatTraversalStatEvent",
	"k_EMsgClientAppInfoRequest",
	"k_EMsgClientAppInfoResponse",
	"k_EMsgClientSteamUsageEvent",
	"k_EMsgClientEmailChange",
	"k_EMsgClientPersonalQAChange",
	"k_EMsgClientCheckPassword",
	"k_EMsgClientResetPassword",
	"",
	"k_EMsgClientCheckPasswordResponse",
	"k_EMsgClientResetPasswordResponse",
	"k_EMsgClientSessionToken",
	"k_EMsgClientDRMProblemReport",
	"",
	"",
	"k_EMsgClientLogonBounce",
	"k_EMsgClientSetIgnoreFriend",
	"k_EMsgClientSetIgnoreFriendResponse",
	"k_EMsgClientGetAppOwnershipTicket",
	"k_EMsgClientGetAppOwnershipTicketResponse",
	"",
	"k_EMsgClientGetLobbyListResponse",
	"k_EMsgClientGetLobbyMetadata",
	"k_EMsgClientGetLobbyMetadataResponse",
	"k_EMsgClientVTTCert",
	"k_EMsgClientAppInfoRequestOld",
	"k_EMsgClientAppInfoResponseOld",
	"k_EMsgClientAppInfoUpdate",
	"k_EMsgClientAppInfoChanges",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"k_EMsgClientServerList",
	"k_EMsgClientUpdateInvPos",
	"k_EMsgClientUpdateInvPosResponse",
	"k_EMsgClientDeleteItem",
	"k_EMsgClientDeleteItemResponse",
	"k_EMsgClientLoadItems",
	"k_EMsgClientLoadItemsResponse",
	"k_EMsgClientItemGranted",
	"k_EMsgClientGetFriendsLobbies",
	"k_EMsgClientGetFriendsLobbiesResponse",
	"k_EMsgClientGetLobbyList",
	"k_EMsgClientEmailChangeResponse",
	"k_EMsgClientSecretQAChangeResponse",
	"k_EMsgClientPasswordChange2",
	"k_EMsgClientEmailChange2",
	"k_EMsgClientPersonalQAChange2",
	"k_EMsgClientDRMBlobRequest",
	"k_EMsgClientDRMBlobResponse",
	"k_EMsgClientLookupKey",
	"k_EMsgClientLookupKeyResponse",
	"k_EMsgBaseGameServer",
	"k_EMsgGSDisconnectNotice",
	"",
	"k_EMsgGSStatus",
	"",
	"k_EMsgGSUserPlaying3",
	"k_EMsgGSStatus2",
	"k_EMsgGSStatusUpdate",
	"k_EMsgGSServerType",
	"k_EMsgGSPlayerList",
	"k_EMsgGSGetUserAchievementStatus",
	"k_EMsgGSGetUserAchievementStatusResponse",
	"k_EMsgGSCreateItem",
	"k_EMsgGSCreateItemResponse",
	"k_EMsgGSItemDeleted",
	"k_EMsgGSItemUpdated",
	"k_EMsgGSLoadItems",
	"k_EMsgGSLoadItemsResponse",
	"k_EMsgGSGetPlayStats",
	"k_EMsgGSGetPlayStatsResponse",
	"k_EMsgGSGetUserGroupStatus",
	"k_EMsgAMGetUserGroupStatus",
	"k_EMsgAMGetUserGroupStatusResponse",
	"k_EMsgGSGetUserGroupStatusResponse",
	"k_EMsgGSGrantItem",
	"k_EMsgGSGrantItemResponse",
	"k_EMsgGSDeleteTempItem",
	"k_EMsgGSDeleteTempItemResponse",
	"k_EMsgGSDeleteAllTempItems",
	"k_EMsgGSDeleteAllTempItemsResponse",
	"k_EMsgGSItemGranted",
	"k_EMsgGSUpdateItemQuantity",
	"k_EMsgGSUpdateItemQuantityResponse",
	"k_EMsgGSRestoreOwnedItems",
	"k_EMsgGSRestoreOwnedItemsResponse",
	"k_EMsgGSItemDropped",
	"k_EMsgGSGetReputation",
	"k_EMsgGSGetReputationResponse",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"k_EMsgAdminCmd",
	"",
	"",
	"",
	"k_EMsgAdminCmdResponse",
	"k_EMsgAdminLogListenRequest",
	"k_EMsgAdminLogEvent",
	"k_EMsgLogSearchRequest",
	"k_EMsgLogSearchResponse",
	"k_EMsgLogSearchCancel",
	"k_EMsgUniverseData",
	"",
	"",
	"",
	"k_EMsgRequestStatHistory",
	"k_EMsgStatHistory",
	"",
	"k_EMsgAdminPwLogon",
	"k_EMsgAdminPwLogonResponse",
	"k_EMsgAdminSpew",
	"k_EMsgAdminConsoleTitle",
	"",
	"",
	"k_EMsgAdminGCSpew",
	"k_EMsgAdminGCCommand",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"k_EMsgFBSReqVersion",
	"k_EMsgFBSVersionInfo",
	"k_EMsgFBSForceRefresh",
	"k_EMsgFBSForceBounce",
	"k_EMsgFBSDeployPackage",
	"k_EMsgFBSDeployResponse",
	"k_EMsgFBSUpdateBootstrapper",
	"k_EMsgFBSSetState",
	"k_EMsgFBSApplyOSUpdates",
	"k_EMsgFBSRunCMDScript",
	"k_EMsgFBSRebootBox",
	"k_EMsgFBSSetBigBrotherMode",
	"k_EMsgFBSMinidumpServer",
	"k_EMsgFBSSetShellCount",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"k_EMsgFileXferRequest",
	"k_EMsgFileXferResponse",
	"k_EMsgFileXferData",
	"k_EMsgFileXferEnd",
	"k_EMsgFileXferDataAck",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"k_EMsgChannelAuthChallenge",
	"k_EMsgChannelAuthResponse",
	"k_EMsgChannelAuthResult",
	"k_EMsgChannelEncryptRequest",
	"k_EMsgChannelEncryptResponse",
	"k_EMsgChannelEncryptResult",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"k_EMsgBaseBS",
	"k_EMsgBSPurchaseStart",
	"k_EMsgBSPurchaseResponse",
	"",
	"k_EMsgBSSettleStart",
	"",
	"k_EMsgBSSettleComplete",
	"k_EMsgBSBannedRequest",
	"k_EMsgBSInitPayPalTxn",
	"k_EMsgBSInitPayPalTxnResponse",
	"k_EMsgBSGetPayPalUserInfo",
	"k_EMsgBSGetPayPalUserInfoResponse",
	"",
	"k_EMsgBSRefundTxn",
	"k_EMsgBSRefundTxnResponse",
	"k_EMsgBSGetEvents",
	"k_EMsgBSChaseRFRRequest",
	"k_EMsgBSPaymentInstrBan",
	"k_EMsgBSPaymentInstrBanResponse",
	"k_EMsgBSProcessGCReports",
	"k_EMsgBSProcessPPReports",
	"k_EMsgBSInitGCPayPalTxn",
	"k_EMsgBSInitGCPayPalTxnResponse",
	"k_EMsgBSQueryGCPayPalTxn",
	"k_EMsgBSQueryGCPayPalTxnResponse",
	"k_EMsgBSCommitGCTxn",
	"k_EMsgBSQueryGCOrderStatus",
	"k_EMsgBSQueryGCOrderStatusResponse",
	"k_EMsgBSQueryCBOrderStatus",
	"k_EMsgBSQueryCBOrderStatusResponse",
	"k_EMsgBSRunRedFlagReport",
	"k_EMsgBSQueryPaymentInstUsage",
	"k_EMsgBSQueryPaymentInstResponse",
	"k_EMsgBSQueryTxnExtendedInfo",
	"k_EMsgBSQueryTxnExtendedInfoResponse",
	"k_EMsgBSUpdateConversionRates",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"k_EMsgBaseATS",
	"k_EMsgATSStartStressTest",
	"k_EMsgATSStopStressTest",
	"k_EMsgATSRunFailServerTest",
	"k_EMsgATSUFSPerfTestTask",
	"k_EMsgATSUFSPerfTestResponse",
	"k_EMsgATSCycleTCM",
	"k_EMsgATSInitDRMSStressTest",
	"k_EMsgATSCallTest",
	"k_EMsgATSCallTestReply",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"k_EMsgBaseDP",
	"k_EMsgDPSetPublishingState",
	"k_EMsgDPGamePlayedStats",
	"k_EMsgDPUniquePlayersStat",
	"",
	"k_EMsgDPVacInfractionStats",
	"k_EMsgDPVacBanStats",
	"k_EMsgDPCoplayStats",
	"k_EMsgDPNatTraversalStats",
	"k_EMsgDPSteamUsageEvent",
	"k_EMsgDPVacCertBanStats",
	"k_EMsgDPVacCafeBanStats",
	"k_EMsgDPCloudStats",
	"k_EMsgDPAchievementStats",
	"k_EMsgDPAccountCreationStats",
	"k_EMsgDPGetPlayerCount",
	"k_EMsgDPGetPlayerCountResponse",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"k_EMsgBaseCM",
	"k_EMsgCMSetAllowState",
	"k_EMsgCMSpewAllowState",
	"k_EMsgCMAppInfoResponse",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"k_EMsgBaseDSS",
	"k_EMsgDSSNewFile",
	"k_EMsgDSSCurrentFileList",
	"k_EMsgDSSSynchList",
	"k_EMsgDSSSynchListResponse",
	"k_EMsgDSSSynchSubscribe",
	"k_EMsgDSSSynchUnsubscribe",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"k_EMsgBaseEPM",
	"k_EMsgEPMStartProcess",
	"k_EMsgEPMStopProcess",
	"k_EMsgEPMRestartProcess",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"k_EMsgAMInternalAuthComplete",
	"k_EMsgAMInternalRemoveAMSession",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"k_EMsgISCreateItem",
	"k_EMsgISCreateItemResponse",
	"k_EMsgISRefresh",
	"k_EMsgISCreateSpecificItem",
	"k_EMsgISAssignItemIDs",
	"k_EMsgISAssignItemIDsResponse",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"k_EMsgGCSendClient",
	"k_EMsgAMRelayToGC",
	"k_EMsgGCUpdatePlayedState",
	"k_EMsgGCCmdRevive",
	"k_EMsgGCCmdBounce",
	"k_EMsgGCCmdForceBounce",
	"k_EMsgGCCmdDown",
	"k_EMsgGCCmdDeploy",
	"k_EMsgGCCmdDeployResponse",
	"k_EMsgGCCmdSwitch",
	"k_EMsgAMRefreshSessions",
	"k_EMsgGCUpdateGSState",
	"k_EMsgGCAchievementAwarded",
	"k_EMsgGCSystemMessage",
	"k_EMsgGCValidateSession",
	"k_EMsgGCValidateSessionResponse",
	"k_EMsgGCCmdStatus",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"k_EMsgBaseP2P",
	"k_EMsgP2PTrackerMessage",
	"k_EMsgP2PIntroducerMessage",
	"k_EMsgP2PSeederUpload",
	"k_EMsgP2PSeederUploadResponse",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"k_EMsgBaseSM",
	"k_EMsgSMBuildUGSTables",
	"k_EMsgSMExpensiveReport",
	"k_EMsgSMHourlyReport",
	"k_EMsgSMFishingReport",
	"k_EMsgSMPartitionRenames",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"k_EMsgFailServer",
	"k_EMsgJobHeartbeatTest",
	"k_EMsgJobHeartbeatTestResponse",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"k_EMsgBaseFTSRange",
	"k_EMsgFTSGetBrowseCounts",
	"k_EMsgFTSGetBrowseCountsResponse",
	"k_EMsgFTSBrowseClans",
	"k_EMsgFTSBrowseClansResponse",
	"k_EMsgFTSSearchClansByLocation",
	"k_EMsgFTSSearchClansByLocationResponse",
	"k_EMsgFTSSearchPlayersByLocation",
	"k_EMsgFTSSearchPlayersByLocationResponse",
	"k_EMsgFTSClanDeleted",
	"k_EMsgFTSSearch",
	"k_EMsgFTSSearchResponse",
	"k_EMsgFTSSearchStatus",
	"k_EMsgFTSSearchStatusResponse",
	"k_EMsgFTSGetGSPlayStats",
	"k_EMsgFTSGetGSPlayStatsResponse",
	"k_EMsgFTSGetGSPlayStatsForServer",
	"k_EMsgFTSGetGSPlayStatsForServerResponse",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"k_EMsgBaseCCSRange",
	"k_EMsgCCSGetComments",
	"k_EMsgCCSGetCommentsResponse",
	"k_EMsgCCSAddComment",
	"k_EMsgCCSAddCommentResponse",
	"k_EMsgCCSDeleteComment",
	"k_EMsgCCSDeleteCommentResponse",
	"k_EMsgCCSPreloadComments",
	"k_EMsgCCSNotifyCommentCount",
	"k_EMsgCCSGetCommentsForNews",
	"k_EMsgCCSGetCommentsForNewsResponse",
	"k_EMsgCCSDeleteAllComments",
	"k_EMsgCCSDeleteAllCommentsResponse",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"k_EMsgBaseLBSRange",
	"k_EMsgLBSSetScore",
	"k_EMsgLBSSetScoreResponse",
	"k_EMsgLBSFindOrCreateLB",
	"k_EMsgLBSFindOrCreateLBResponse",
	"k_EMsgLBSGetLBEntries",
	"k_EMsgLBSGetLBEntriesResponse",
	"k_EMsgLBSGetLBList",
	"k_EMsgLBSGetLBListResponse",
	"k_EMsgLBSSetLBDetails",
	"k_EMsgLBSDeleteLB",
	"k_EMsgLBSDeleteLBEntry",
	"k_EMsgLBSResetLB",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"k_EMsgBaseOGS",
	"k_EMsgOGSBeginSession",
	"k_EMsgOGSBeginSessionResponse",
	"k_EMsgOGSEndSession",
	"k_EMsgOGSEndSessionResponse",
	"k_EMsgOGSWriteRow",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"k_EMsgBaseAMRange2",
	"k_EMsgAMCreateChat",
	"k_EMsgAMCreateChatResponse",
	"k_EMsgAMUpdateChatMetadata",
	"k_EMsgAMPublishChatMetadata",
	"k_EMsgAMSetProfileURL",
	"k_EMsgAMGetAccountEmailAddress",
	"k_EMsgAMGetAccountEmailAddressResponse",
	"k_EMsgAMRequestFriendData",
	"k_EMsgAMRouteToClients",
	"k_EMsgAMLeaveClan",
	"k_EMsgAMClanPermissions",
	"k_EMsgAMClanPermissionsResponse",
	"k_EMsgAMCreateClanEvent",
	"k_EMsgAMCreateClanEventResponse",
	"k_EMsgAMUpdateClanEvent",
	"k_EMsgAMUpdateClanEventResponse",
	"k_EMsgAMGetClanEvents",
	"k_EMsgAMGetClanEventsResponse",
	"k_EMsgAMDeleteClanEvent",
	"k_EMsgAMDeleteClanEventResponse",
	"k_EMsgAMSetClanPermissionSettings",
	"k_EMsgAMSetClanPermissionSettingsResponse",
	"k_EMsgAMGetClanPermissionSettings",
	"k_EMsgAMGetClanPermissionSettingsResponse",
	"k_EMsgAMPublishChatRoomInfo",
	"k_EMsgClientChatRoomInfo",
	"k_EMsgAMCreateClanAnnouncement",
	"k_EMsgAMCreateClanAnnouncementResponse",
	"k_EMsgAMUpdateClanAnnouncement",
	"k_EMsgAMUpdateClanAnnouncementResponse",
	"k_EMsgAMGetClanAnnouncementsCount",
	"k_EMsgAMGetClanAnnouncementsCountResponse",
	"k_EMsgAMGetClanAnnouncements",
	"k_EMsgAMGetClanAnnouncementsResponse",
	"k_EMsgAMDeleteClanAnnouncement",
	"k_EMsgAMDeleteClanAnnouncementResponse",
	"k_EMsgAMGetSingleClanAnnouncement",
	"k_EMsgAMGetSingleClanAnnouncementResponse",
	"k_EMsgAMGetClanHistory",
	"k_EMsgAMGetClanHistoryResponse",
	"k_EMsgAMGetClanPermissionBits",
	"k_EMsgAMGetClanPermissionBitsResponse",
	"k_EMsgAMSetClanPermissionBits",
	"k_EMsgAMSetClanPermissionBitsResponse",
	"k_EMsgAMSessionInfoRequest",
	"k_EMsgAMSessionInfoResponse",
	"k_EMsgAMValidateWGToken",
	"k_EMsgAMGetSingleClanEvent",
	"k_EMsgAMGetSingleClanEventResponse",
	"k_EMsgAMGetClanRank",
	"k_EMsgAMGetClanRankResponse",
	"k_EMsgAMSetClanRank",
	"k_EMsgAMSetClanRankResponse",
	"k_EMsgAMGetClanPOTW",
	"k_EMsgAMGetClanPOTWResponse",
	"k_EMsgAMSetClanPOTW",
	"k_EMsgAMSetClanPOTWResponse",
	"k_EMsgAMRequestChatMetadata",
	"k_EMsgAMDumpUser",
	"k_EMsgAMKickUserFromClan",
	"k_EMsgAMAddFounderToClan",
	"k_EMsgAMValidateWGTokenResponse",
	"k_EMsgAMSetCommunityState",
	"k_EMsgAMSetAccountDetails",
	"k_EMsgAMGetChatBanList",
	"k_EMsgAMGetChatBanListResponse",
	"k_EMsgAMUnBanFromChat",
	"k_EMsgAMSetClanDetails",
	"k_EMsgAMGetAccountLinks",
	"k_EMsgAMGetAccountLinksResponse",
	"k_EMsgAMSetAccountLinks",
	"k_EMsgAMSetAccountLinksResponse",
	"k_EMsgAMGetUserGameStats",
	"k_EMsgAMGetUserGameStatsResponse",
	"k_EMsgAMCheckClanMembership",
	"k_EMsgAMGetClanMembers",
	"k_EMsgAMGetClanMembersResponse",
	"k_EMsgAMJoinPublicClan",
	"k_EMsgAMNotifyChatOfClanChange",
	"k_EMsgAMResubmitPurchase",
	"k_EMsgAMAddFriend",
	"k_EMsgAMAddFriendResponse",
	"k_EMsgAMRemoveFriend",
	"k_EMsgAMGetVIPStatus",
	"k_EMsgAMVIPStatusResponse",
	"k_EMsgAMCancelEasyCollect",
	"k_EMsgAMCancelEasyCollectResponse",
	"k_EMsgAMGetClanMembershipList",
	"k_EMsgAMGetClanMembershipListResponse",
	"k_EMsgAMClansInCommon",
	"k_EMsgAMClansInCommonResponse",
	"k_EMsgAMIsValidAccountID",
	"k_EMsgAMConvertClan",
	"k_EMsgAMGetGiftTargetListRelay",
	"k_EMsgAMWipeFriendsList",
	"k_EMsgAMSetIgnored",
	"k_EMsgAMClansInCommonCountResponse",
	"k_EMsgAMFriendsList",
	"k_EMsgAMFriendsListResponse",
	"k_EMsgAMFriendsInCommon",
	"k_EMsgAMFriendsInCommonResponse",
	"k_EMsgAMFriendsInCommonCountResponse",
	"k_EMsgAMClansInCommonCount",
	"k_EMsgAMChallengeVerdict",
	"k_EMsgAMChallengeNotification",
	"k_EMsgAMFindGSByIP",
	"k_EMsgAMFoundGSByIP",
	"k_EMsgAMGiftRevoked",
	"k_EMsgAMCreateAccountRecord",
	"k_EMsgAMUserClanList",
	"k_EMsgAMUserClanListResponse",
	"k_EMsgAMGetAccountDetails2",
	"k_EMsgAMGetAccountDetailsResponse2",
	"k_EMsgAMSetCommunityProfileSettings",
	"k_EMsgAMSetCommunityProfileSettingsResponse",
	"k_EMsgAMGetCommunityPrivacyState",
	"k_EMsgAMGetCommunityPrivacyStateResponse",
	"k_EMsgAMCheckClanInviteRateLimiting",
	"k_EMsgAMGetUserAchievementStatus",
	"k_EMsgAMGetIgnored",
	"k_EMsgAMGetIgnoredResponse",
	"k_EMsgAMSetIgnoredResponse",
	"k_EMsgAMSetFriendRelationshipNone",
	"k_EMsgAMGetFriendRelationship",
	"k_EMsgAMGetFriendRelationshipResponse",
	"k_EMsgAMServiceModulesCache",
	"k_EMsgAMServiceModulesCall",
	"k_EMsgAMServiceModulesCallResponse",
	"k_EMsgAMGetCaptchaDataForIP",
	"k_EMsgAMGetCaptchaDataForIPResponse",
	"k_EMsgAMValidateCaptchaDataForIP",
	"k_EMsgAMValidateCaptchaDataForIPResponse",
	"k_EMsgAMTrackFailedAuthByIP",
	"k_EMsgAMGetCaptchaDataByGID",
	"k_EMsgAMGetCaptchaDataByGIDResponse",
	"k_EMsgAMGetLobbyList",
	"k_EMsgAMGetLobbyListResponse",
	"k_EMsgAMGetLobbyMetadata",
	"k_EMsgAMGetLobbyMetadataResponse",
	"k_EMsgAMAddFriendNews",
	"k_EMsgAMAddClanNews",
	"k_EMsgAMWriteNews",
	"k_EMsgAMFindClanUser",
	"k_EMsgAMFindClanUserResponse",
	"k_EMsgAMBanFromChat",
	"k_EMsgAMGetUserHistoryResponse",
	"k_EMsgAMGetUserNewsSubscriptions",
	"k_EMsgAMGetUserNewsSubscriptionsResponse",
	"k_EMsgAMSetUserNewsSubscriptions",
	"k_EMsgAMGetUserNews",
	"k_EMsgAMGetUserNewsResponse",
	"k_EMsgAMSendQueuedEmails",
	"k_EMsgAMSetLicenseFlags",
	"k_EMsgAMGetUserHistory",
	"k_EMsgAMDeleteUserNews",
	"k_EMsgAMAllowUserFilesRequest",
	"k_EMsgAMAllowUserFilesResponse",
	"k_EMsgAMGetAccountStatus",
	"k_EMsgAMGetAccountStatusResponse",
	"k_EMsgAMEditBanReason",
	"",
	"k_EMsgAMProbeClanMembershipList",
	"k_EMsgAMProbeClanMembershipListResponse",
	"k_EMsgAMRouteClientMsgToAM",
	"k_EMsgAMGetFriendsLobbies",
	"k_EMsgAMGetFriendsLobbiesResponse",
	"k_EMsgAMLoadItems",
	"k_EMsgAMLoadItemsResponse",
	"k_EMsgAMCacheNewItem",
	"k_EMsgAMRelayItemUpdateGS",
	"k_EMsgAMRelayItemDeletedGS",
	"k_EMsgAMGetUserFriendNewsResponse",
	"k_EMsgAMGetUserFriendNews",
	"k_EMsgAMGetUserClansNewsResponse",
	"k_EMsgAMGetUserClansNews",
	"k_EMsgAMStoreInitPurchase",
	"k_EMsgAMStoreInitPurchaseResponse",
	"k_EMsgAMStoreGetFinalPrice",
	"k_EMsgAMStoreGetFinalPriceResponse",
	"k_EMsgAMStoreCompletePurchase",
	"k_EMsgAMStoreCancelPurchase",
	"k_EMsgAMStorePurchaseResponse",
	"k_EMsgAMCreateAccountRecordInSteam3",
	"k_EMsgAMGetPreviousCBAccount",
	"k_EMsgAMGetPreviousCBAccountResponse",
	"k_EMsgAMUpdateBillingAddress",
	"k_EMsgAMUpdateBillingAddressResponse",
	"k_EMsgAMGetBillingAddress",
	"k_EMsgAMGetBillingAddressResponse",
	"k_EMsgAMGetUserLicenseHistory",
	"k_EMsgAMGetUserLicenseHistoryResponse",
	"k_EMsgAMGetUserTransactionHistory",
	"k_EMsgAMGetUserTransactionHistoryResponse",
	"k_EMsgAMSupportChangePassword",
	"k_EMsgAMSupportChangeEmail",
	"k_EMsgAMSupportChangeSecretQA",
	"k_EMsgAMResetUserVerificationGSByIP",
	"k_EMsgAMUpdateGSPlayStats",
	"k_EMsgAMSupportEnableOrDisable",
	"k_EMsgAMGetComments",
	"k_EMsgAMGetCommentsResponse",
	"k_EMsgAMAddComment",
	"k_EMsgAMAddCommentResponse",
	"k_EMsgAMDeleteComment",
	"k_EMsgAMDeleteCommentResponse",
	"k_EMsgAMGetPurchaseStatus",
	"k_EMsgAMChatDetailsQuery",
	"k_EMsgAMChatDetailsResponse",
	"k_EMsgAMSupportIsAccountEnabled",
	"k_EMsgAMSupportIsAccountEnabledResponse",
	"k_EMsgAMGetUserStats",
	"k_EMsgAMSupportKickSession",
	"k_EMsgAMGSSearch",
	"k_EMsgAMAwardItem",
	"k_EMsgAMRelayItemAwardedGS",
	"k_EMsgMarketingMessageUpdate",
	"k_EMsgAMRelayItemQuantityUpdated",
	"k_EMsgAMRelayItemQuantityUpdatedResponse",
	"k_EMsgAMRouteFriendMsg",
	"k_EMsgAMTicketAuthRequestOrResponse",
	"k_EMsgAMFlushItemCaches",
	"k_EMsgAMVerifyDepotManagementRights",
	"k_EMsgAMVerifyDepotManagementRightsResponse",
	"k_EMsgAMAddFreeLicense",
	"k_EMsgAMGetUserFriendsMinutesPlayed",
	"k_EMsgAMGetUserFriendsMinutesPlayedResponse",
	"k_EMsgAMGetUserMinutesPlayed",
	"k_EMsgAMGetUserMinutesPlayedResponse",
	"k_EMsgAMReloadAccountItemSection",
	"k_EMsgAMRelayCurrentCoplayCount",
	"k_EMsgAMValidateEmailLink",
	"k_EMsgAMValidateEmailLinkResponse",
	"k_EMsgAMReportDroppedItemGS",
	"k_EMsgAMAddUsersToMarketingTreatment",
	"k_EMsgAMAddItemListToUser",
	"k_EMsgAMStoreUserStats",
	"k_EMsgAMGetUserGameplayInfo",
	"k_EMsgAMGetUserGameplayInfoResponse",
	"k_EMsgAMGetCardList",
	"k_EMsgAMGetCardListResponse",
	"k_EMsgAMDeleteStoredCard",
	"k_EMsgAMRevokeLegacyGameKeys",
	"k_EMsgAMCommitPurchasedItem",
	"k_EMsgAMGetWalletDetails",
	"k_EMsgAMGetWalletDetailsResponse",
	"k_EMsgAMDeleteStoredPaymentInfo",
	"k_EMsgAMGetStoredPaymentSummary",
	"k_EMsgAMGetStoredPaymentSummaryResponse",
	"k_EMsgAMGetWalletConversionRate",
	"k_EMsgAMGetWalletConversionRateResponse",
	"k_EMsgAMConvertWallet",
	"k_EMsgAMConvertWalletResponse",
	"k_EMsgAMRelayGetFriendsWhoPlayGame",
	"k_EMsgAMRelayGetFriendsWhoPlayGameResponse",
	"k_EMsgAMSetPreApproval",
	"k_EMsgAMSetPreApprovalResponse",
	"k_EMsgAMMarketingTreatmentUpdate",
	"k_EMsgAMCreateRefund",
	"k_EMsgAMCreateRefundResponse",
	"k_EMsgAMCreateChargeback",
	"k_EMsgAMCreateChargebackResponse",
	"k_EMsgAMCreateDispute",
	"k_EMsgAMCreateDisputeResponse",
	"k_EMsgAMClearDispute",
	"k_EMsgAMClearDisputeResponse",
	"k_EMsgCAMQueryPersonaStateCache",
	"k_EMsgCAMQueryPersonaStateCacheResponse",
	"k_EMsgAMSetDRMTestConfig",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"k_EMsgBasePSRange",
	"k_EMsgPSCreateShoppingCart",
	"k_EMsgPSCreateShoppingCartResponse",
	"k_EMsgPSIsValidShoppingCart",
	"k_EMsgPSIsValidShoppingCartResponse",
	"k_EMsgPSAddPackageToShoppingCart",
	"k_EMsgPSAddPackageToShoppingCartResponse",
	"k_EMsgPSRemoveLineItemFromShoppingCart",
	"k_EMsgPSRemoveLineItemFromShoppingCartResponse",
	"k_EMsgPSGetShoppingCartContents",
	"k_EMsgPSGetShoppingCartContentsResponse",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"k_EMsgBaseUFSRange",
	"",
	"k_EMsgClientUFSUploadFileRequest",
	"k_EMsgClientUFSUploadFileResponse",
	"k_EMsgClientUFSUploadFileChunk",
	"k_EMsgClientUFSUploadFileFinished",
	"k_EMsgClientUFSGetFileListForApp",
	"k_EMsgClientUFSGetFileListForAppResponse",
	"k_EMsgRouteClientMsgToUFS",
	"k_EMsgRouteUFSMsgToClient",
	"k_EMsgClientUFSDownloadRequest",
	"k_EMsgClientUFSDownloadResponse",
	"k_EMsgClientUFSDownloadChunk",
	"k_EMsgClientUFSLoginRequest",
	"k_EMsgClientUFSLoginResponse",
	"k_EMsgUFSReloadPartitionInfo",
	"k_EMsgClientUFSTransferHeartbeat",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"k_EMsgBaseClient2",
	"k_EMsgClientRequestForgottenPasswordEmail",
	"k_EMsgClientRequestForgottenPasswordEmailResponse",
	"k_EMsgClientCreateAccountResponse",
	"k_EMsgClientResetForgottenPassword",
	"k_EMsgClientResetForgottenPasswordResponse",
	"k_EMsgClientCreateAccount2",
	"k_EMsgClientInformOfResetForgottenPassword",
	"k_EMsgClientInformOfResetForgottenPasswordResponse",
	"k_EMsgClientAnonUserLogOn",
	"k_EMsgClientGamesPlayedWithDataBlob",
	"k_EMsgClientUpdateUserGameInfo",
	"k_EMsgClientFileToDownload",
	"k_EMsgClientFileToDownloadResponse",
	"k_EMsgClientLBSSetScore",
	"k_EMsgClientLBSSetScoreResponse",
	"k_EMsgClientLBSFindOrCreateLB",
	"k_EMsgClientLBSFindOrCreateLBResponse",
	"k_EMsgClientLBSGetLBEntries",
	"k_EMsgClientLBSGetLBEntriesResponse",
	"k_EMsgClientMarketingMessageUpdate",
	"k_EMsgClientGetItemBlob",
	"k_EMsgClientGetItemBlobResponse",
	"k_EMsgClientSetItemBlob",
	"k_EMsgClientSetItemBlobResponse",
	"k_EMsgClientItemQuantityUpdated",
	"k_EMsgClientChatDeclined",
	"k_EMsgClientFriendMsgIncoming",
	"k_EMsgClientAuthList",
	"k_EMsgClientTicketAuthComplete",
	"k_EMsgClientIsLimitedAccount",
	"k_EMsgClientRequestAuthList",
	"k_EMsgClientAuthList2",
	"k_EMsgClientStat",
	"k_EMsgClientP2PConnectionInfo",
	"k_EMsgClientP2PConnectionFailInfo",
	"k_EMsgClientGetNumberOfCurrentPlayers",
	"k_EMsgClientGetNumberOfCurrentPlayersResponse",
	"k_EMsgClientGetDepotDecryptionKey",
	"k_EMsgClientGetDepotDecryptionKeyResponse",
	"k_EMsgGSPerformHardwareSurvey",
	"k_EMsgClientCheckForUpdatedDepotManifest",
	"k_EMsgClientCheckForUpdatedDepotManifestResponse",
	"k_EMsgClientEnableTestLicense",
	"k_EMsgClientEnableTestLicenseResponse",
	"k_EMsgClientDisableTestLicense",
	"k_EMsgClientDisableTestLicenseResponse",
	"",
	"k_EMsgClientRequestValidationMail",
	"k_EMsgClientRequestValidationMailResponse",
	"k_EMsgClientDropItem",
	"k_EMsgClientDropItemResponse",
	"k_EMsgClientToGC",
	"k_EMsgClientFromGC",
	"k_EMsgClientRequestChangeMail",
	"k_EMsgClientRequestChangeMailResponse",
	"k_EMsgClientEmailAddrInfo",
	"k_EMsgClientPasswordChange3",
	"k_EMsgClientEmailChange3",
	"k_EMsgClientPersonalQAChange3",
	"k_EMsgClientResetForgottenPassword3",
	"k_EMsgClientRequestForgottenPasswordEmail3",
	"k_EMsgClientCreateAccount3",
	"k_EMsgClientNewLoginKey",
	"k_EMsgClientNewLoginKeyAccepted",
	"k_EMsgClientLogOnWithHash",
	"k_EMsgClientStoreUserStats2",
	"k_EMsgClientStatsUpdated",
	"k_EMsgClientActivateOEMLicense",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"k_EMsgClientRequestedClientStats",
	"k_EMsgClientStat2Int32",
	"k_EMsgClientStat2",
	"k_EMsgClientVerifyPassword",
	"k_EMsgClientVerifyPasswordResponse",
	"k_EMsgClientDRMDownloadRequest",
	"k_EMsgClientDRMDownloadResponse",
	"k_EMsgClientDRMFinalResult",
	"k_EMsgClientGetFriendsWhoPlayGame",
	"k_EMsgClientGetFriendsWhoPlayGameResponse",
	"k_EMsgClientOGSBeginSession",
	"k_EMsgClientOGSBeginSessionResponse",
	"k_EMsgClientOGSEndSession",
	"k_EMsgClientOGSEndSessionResponse",
	"k_EMsgClientOGSWriteRow",
	"k_EMsgClientDRMTest",
	"k_EMsgClientDRMTestResult",
	"",
	"",
	"",
	"k_EMsgClientServerUnavailable",
	"k_EMsgClientServersAvailable",
	"k_EMsgClientRegisterAuthTicketWithCM",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"k_EMsgBaseDFS",
	"k_EMsgDFSGetFile",
	"k_EMsgDFSInstallLocalFile",
	"k_EMsgDFSConnection",
	"k_EMsgDFSConnectionReply",
	"k_EMsgClientDFSAuthenticateRequest",
	"k_EMsgClientDFSAuthenticateResponse",
	"k_EMsgClientDFSEndSession",
	"k_EMsgDFSPurgeFile",
	"k_EMsgDFSRouteFile",
	"k_EMsgDFSGetFileFromServer",
	"k_EMsgDFSAcceptedResponse",
	"k_EMsgDFSRequestPingback",
	"k_EMsgDFSRecvTransmitFile",
	"k_EMsgDFSSendTransmitFile",
	"k_EMsgDFSRequestPingback2",
	"k_EMsgDFSResponsePingback2",
	"k_EMsgClientDFSDownloadStatus",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"k_EMsgBaseMDS",
	"k_EMsgClientMDSLoginRequest",
	"k_EMsgClientMDSLoginResponse",
	"k_EMsgClientMDSUploadManifestRequest",
	"k_EMsgClientMDSUploadManifestResponse",
	"k_EMsgClientMDSTransmitManifestDataChunk",
	"k_EMsgClientMDSHeartbeat",
	"k_EMsgClientMDSUploadDepotChunks",
	"k_EMsgClientMDSUploadDepotChunksResponse",
	"k_EMsgClientMDSInitDepotBuildRequest",
	"k_EMsgClientMDSInitDepotBuildResponse",
	"k_EMsgClientMDSChunkListResponse",
	"k_EMsgAMToMDSGetDepotDecryptionKey",
	"k_EMsgMDSToAMGetDepotDecryptionKeyResponse",
	"k_EMsgMDSGetVersionsForDepot",
	"k_EMsgMDSGetVersionsForDepotResponse",
	"k_EMsgMDSSetPublicVersionForDepot",
	"k_EMsgMDSSetPublicVersionForDepotResponse",
	"k_EMsgClientMDSGetDepotManifest",
	"k_EMsgClientMDSGetDepotManifestResponse",
	"k_EMsgClientMDSGetDepotManifestChunk",
	"k_EMsgAMToMDSCheckForUpdatedDepotManifest",
	"k_EMsgMDSToAMCheckForUpdatedDepotManifestResponse",
	"k_EMsgClientMDSDownloadDepotChunksRequest",
	"k_EMsgClientMDSDownloadDepotChunksAsync",
	"k_EMsgClientMDSDownloadDepotChunksAck",
	"k_EMsgMDSContentServerStatsBroadcast",
	"k_EMsgMDSContentServerConfigRequest",
	"k_EMsgMDSContentServerConfig",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"",
	"k_EMsgCSBase",
	"k_EMsgClientCSLoginRequest",
	"k_EMsgClientCSLoginResponse",
	"k_EMsgClientCSGetDepotManifest",
	"k_EMsgClientCSGetDepotManifestResponse",
};

/*
const char *PchNameFromEMsg( EMsg eMsg )
{
	if ( eMsg <= k_EMsgInvalid || eMsg > k_EMsgClientCSGetDepotManifestResponse )
		return k_szEMsg[ 0 ];

	return k_szEMsg[ (int)eMsg ];
}
*/

const char *k_szEResult[] =
{
	"Invalid EResult",
	"k_EResultOK",
	"k_EResultFail",
	"k_EResultNoConnection",
	"k_EResultNoConnectionRetry",
	"k_EResultInvalidPassword",
	"k_EResultLoggedInElsewhere",
	"k_EResultInvalidProtocolVer",
	"k_EResultInvalidParam",
	"k_EResultFileNotFound",
	"k_EResultBusy",
	"k_EResultInvalidState",
	"k_EResultInvalidName",
	"k_EResultInvalidEmail",
	"k_EResultDuplicateName",
	"k_EResultAccessDenied",
	"k_EResultTimeout",
	"k_EResultBanned",
	"k_EResultAccountNotFound",
	"k_EResultInvalidSteamID",
	"k_EResultServiceUnavailable",
	"k_EResultNotLoggedOn",
	"k_EResultPending",
	"k_EResultEncryptionFailure",
	"k_EResultInsufficientPrivilege",
	"k_EResultLimitExceeded",
	"k_EResultRevoked",
	"k_EResultExpired",
	"k_EResultAlreadyRedeemed",
	"k_EResultDuplicateRequest",
	"k_EResultAlreadyOwned",
	"k_EResultIPNotFound",
	"k_EResultPersistFailed",
	"k_EResultLockingFailed",
	"k_EResultLogonSessionReplaced",
	"k_EResultConnectFailed",
	"k_EResultHandshakeFailed",
	"k_EResultIOFailure",
	"k_EResultRemoteDisconnect",
	"k_EResultShoppingCartNotFound",
	"k_EResultBlocked",
	"k_EResultIgnored",
	"k_EResultNoMatch",
	"k_EResultAccountDisabled",
	"k_EResultServiceReadOnly",
	"k_EResultAccountNotFeatured",
	"k_EResultAdministratorOK",
	"k_EResultContentVersion",
	"k_EResultTryAnotherCM",
	"k_EResultPasswordRequiredToKickSession",
	"k_EResultAlreadyLoggedInElsewhere",
	"k_EResultSuspended",
	"k_EResultCancelled",
	"k_EResultDataCorruption",
	"k_EResultDiskFull",
	"k_EResultRemoteCallFailed",
};

const char *PchNameFromEResult( EResult eResult )
{
	if ( eResult <= 0 || eResult >= 55 )
		return k_szEResult[ 0 ];

	return k_szEResult[ (int)eResult ];
}

const char *k_szEAccountType[] =
{
	"k_EAccountTypeInvalid",
	"k_EAccountTypeIndividual",
	"k_EAccountTypeMultiseat",
	"k_EAccountTypeGameServer",
	"k_EAccountTypeAnonGameServer",
	"k_EAccountTypePending",
	"k_EAccountTypeContentServer",
	"k_EAccountTypeClan",
	"k_EAccountTypeChat",
	"k_EAccountTypeP2PSuperSeeder",
	"k_EAccountTypeAnonUser",
};

const char *PchNameFromEAccountType( EAccountType eAccountType )
{
	if ( eAccountType <= 0 || eAccountType >= k_EAccountTypeMax )
		return k_szEAccountType[ 0 ];

	return k_szEAccountType[ (int)eAccountType ];
}

const char *PchStringFromSockAddr( const sockaddr_in *sockAddr )
{
	static char szSockAddr[ 22 ];
	memset( szSockAddr, 0, sizeof( szSockAddr ) );

	if ( !sockAddr )
		return NULL;

	sprintf_s( szSockAddr, sizeof( szSockAddr ), "%s:%hu", inet_ntoa( sockAddr->sin_addr ), ntohs( sockAddr->sin_port ) );

	return szSockAddr;
}